        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 24 <br>1,5,9,11,13,14,18,19,20,23,24,25,26,28,31,35,36,39,41,42,45,47,48,50';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 20 <strong>control</strong><br>0,2,7,8,10,12,17,21,22,29,30,32,33,34,37,38,43,44,46,49';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 7 <br>3,4,6,15,16,27,40';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 24 <br>1,5,9,11,13,14,18,19,20,23,24,25,26,28,31,35,36,39,41,42,45,47,48,50';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 20 <strong>control</strong><br>0,2,7,8,10,12,17,21,22,29,30,32,33,34,37,38,43,44,46,49';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 7 <br>3,4,6,15,16,27,40';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 24 <br>1,5,9,11,13,14,18,19,20,23,24,25,26,28,31,35,36,39,41,42,45,47,48,50';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 20 <strong>control</strong><br>0,2,7,8,10,12,17,21,22,29,30,32,33,34,37,38,43,44,46,49';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 7 <br>3,4,6,15,16,27,40';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 24 <br>1,5,9,11,13,14,18,19,20,23,24,25,26,28,31,35,36,39,41,42,45,47,48,50';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 20 <strong>control</strong><br>0,2,7,8,10,12,17,21,22,29,30,32,33,34,37,38,43,44,46,49';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 7 <br>3,4,6,15,16,27,40';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 24 <br>1,5,9,11,13,14,18,19,20,23,24,25,26,28,31,35,36,39,41,42,45,47,48,50';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 20 <strong>control</strong><br>0,2,7,8,10,12,17,21,22,29,30,32,33,34,37,38,43,44,46,49';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 7 <br>3,4,6,15,16,27,40';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 24 <br>1,5,9,11,13,14,18,19,20,23,24,25,26,28,31,35,36,39,41,42,45,47,48,50';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 20 <strong>control</strong><br>0,2,7,8,10,12,17,21,22,29,30,32,33,34,37,38,43,44,46,49';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 7 <br>3,4,6,15,16,27,40';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 12 a 24 UTC (mm)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 12 a 24 UTC (mm)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 24 <br>1,5,9,11,13,14,18,19,20,23,24,25,26,28,31,35,36,39,41,42,45,47,48,50';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 12 a 24 UTC (mm)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 20 <strong>control</strong><br>0,2,7,8,10,12,17,21,22,29,30,32,33,34,37,38,43,44,46,49';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 12 a 24 UTC (mm)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 7 <br>3,4,6,15,16,27,40';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 12 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 12 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 24 <br>1,5,9,11,13,14,18,19,20,23,24,25,26,28,31,35,36,39,41,42,45,47,48,50';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 12 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 20 <strong>control</strong><br>0,2,7,8,10,12,17,21,22,29,30,32,33,34,37,38,43,44,46,49';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 12 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 7 <br>3,4,6,15,16,27,40';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 24 <br>1,5,9,11,13,14,18,19,20,23,24,25,26,28,31,35,36,39,41,42,45,47,48,50';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 20 <strong>control</strong><br>0,2,7,8,10,12,17,21,22,29,30,32,33,34,37,38,43,44,46,49';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260518 a 00</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 7 <br>3,4,6,15,16,27,40';}
}
